:py:mod:`piel.tools.hdl21.simulator`
====================================

.. py:module:: piel.tools.hdl21.simulator


Module Contents
---------------


Functions
~~~~~~~~~

.. autoapisummary::

   piel.tools.hdl21.simulator.configure_transient_simulation



.. py:function:: configure_transient_simulation(circuit: hdl21.Module, stop_time_s: float, step_time_s: float)

   This function configures the transient simulation for the circuit.
